import scrapy

from crawl.comm.lottery import LotteryResult, LotteryResultDetail


class LotterySpider(scrapy.Spider):
  name = "lottery"

  def start_requests(self):
    # 大乐透
    url = "https://www.lottery.gov.cn/api/lottery_kj_detail_new.jspx?_ltype=4"
    yield scrapy.Request(url, self.parseLottery, 'POST')

    # 排列三, 排列五
    url = "https://www.lottery.gov.cn/api/lottery_kj_detail_new.jspx?_ltype=5"
    yield scrapy.Request(url, self.parsePermutation, 'POST')

    # 双色球
    url = "http://www.cwl.gov.cn/cwl_admin/kjxx/findDrawNotice?name=ssq&issueCount=1"
    yield scrapy.Request(url, self.parseDraw)

  # 大乐透
  def parseLottery(self, response):
    data = response.json()
    data = data[0]

    # 大乐透
    typ = 'lottery'
    result = LotteryResult(
      typ,
      data['lottery']['term'],
      data['lottery']['fTime'][0:10],
      '|'.join(data['codeNumber'])
    )

    details = []
    for i, item in enumerate(data['details']):
      detail = LotteryResultDetail(item.get('level'), item.get('piece'), item.get('money'))
      detail.add(data['detailsAdd'][i].get('piece'), data['detailsAdd'][i].get('money'))
      details.append(detail)
    result.setDetails(details)

    result.persist()

  # 排列三, 排列五
  def parsePermutation(self, response):
    data = response.json()
    data = data[0]

    issueNo = data['lottery']['term']
    openingDate = data['lottery']['fTime'][0:10]

    # 排列三
    typ = 'p3'
    result = LotteryResult(
      typ,
      issueNo,
      openingDate,
      '|'.join(data['codeNumber'])
    )

    details = []
    for i, item in enumerate(data['details']):
      detail = LotteryResultDetail(item.get('level'), item.get('piece'), item.get('money'))
      details.append(detail)

    result.setDetails(details)
    result.persist()

    # 排列五
    typ = 'p5'
    result = LotteryResult(
      typ,
      issueNo,
      openingDate,
      '|'.join(data['codeNumberPlw'])
    )

    details = []
    for i, item in enumerate(data['detailsPlw']):
      detail = LotteryResultDetail(item.get('level'), item.get('piece'), item.get('money'))
      details.append(detail)

    result.setDetails(details)
    result.persist()

  # 福彩 - 双色球
  def parseDraw(self, response):
    data = response.json()
    data = data['result'][0]

    typ = 'double-color'
    result = LotteryResult(
      typ,
      data['code'],
      data['date'][0:10],
      '|'.join(data['red'].split(',') + [data['blue']])
    )

    details = []
    for i, item in enumerate(data['prizegrades']):
      level = item.get('type')
      if level == 1:
        level = '一等奖'
      elif level == 2:
        level = '二等奖'
      elif level == 3:
        level = '三等奖'
      elif level == 4:
        level = '四等奖'
      elif level == 5:
        level = '五等奖'
      elif level == 6:
        level = '六等奖'
      else:
        continue

      detail = LotteryResultDetail(level, item.get('typenum'), item.get('typemoney'))
      details.append(detail)

    result.setDetails(details)
    result.persist()

